# Release notes

<!-- do not remove -->

## 0.1.14

### New Features

- `text` property for `GhEvent` ([#23](https://github.com/fastai/ghapi/issues/23))

### Bugs Squashed

- broken links in index.html page ([#27](https://github.com/fastai/ghapi/issues/27))
- Bug: `paged` does not pass `kwargs` to operation ([#24](https://github.com/fastai/ghapi/issues/24))


## 0.1.13


### Bugs Squashed

- missing import in auth ([#21](https://github.com/fastai/ghapi/issues/21))


## 0.1.11

### Bugs Squashed

- missing webbrowser import ([#20](https://github.com/fastai/ghapi/issues/20))


## 0.1.10

- Add `load_sample_events`, which loads a file of 1000 sample public events


## 0.1.8

### New Features

- add `fetch_events` ([#19](https://github.com/fastai/ghapi/issues/19))


## 0.1.7

### New Features

- parallel `pages` ([#18](https://github.com/fastai/ghapi/issues/18))
- add `GhDeviceAuth` ([#15](https://github.com/fastai/ghapi/issues/15))
- add `date2gh` ([#14](https://github.com/fastai/ghapi/issues/14))


## 0.1.6

### New Features

- add `paged` ([#13](https://github.com/fastai/ghapi/issues/13))
- add `gh_date` ([#12](https://github.com/fastai/ghapi/issues/12))


## 0.1.1

### New Features

- add `list_tags` and `list_branches` ([#2](https://github.com/fastai/ghapi/issues/2))

### Bugs Squashed

- `GhApi` pickle recursion error ([#3](https://github.com/fastai/ghapi/issues/3))


## 0.1.0

- First release with full API coverage

